import React from 'react';
import { TouchableOpacity, StyleSheet } from 'react-native';
import EmojiSelector from 'react-native-emoji-selector';
import { MaterialCommunityIcons } from '@expo/vector-icons';
import Animated, { SlideInDown, SlideOutDown } from 'react-native-reanimated';
import { Colors } from 'src/theme';

interface EmojiSelectorModalProps {
  visible: boolean;
  addReaction: (messageId: number, emoji: string) => void;
  selectedMessage: any;
  closeEmojiSelector: () => void;
}

const EmojiSelectorModal: React.FC<EmojiSelectorModalProps> = ({
  visible,
  addReaction,
  selectedMessage,
  closeEmojiSelector
}) =>
  visible && (
    <Animated.View
      entering={SlideInDown}
      exiting={SlideOutDown}
      style={styles.emojiSelectorContainer}
    >
      <EmojiSelector
        onEmojiSelected={(emoji) => {
          addReaction(selectedMessage?.currentMessage?._id, emoji);
          closeEmojiSelector();
        }}
        showSearchBar={true}
        columns={8}
      />
      <TouchableOpacity style={styles.closeModalButton} onPress={closeEmojiSelector}>
        <MaterialCommunityIcons name="close" size={30} color={Colors.DARK_BLUE} />
      </TouchableOpacity>
    </Animated.View>
  );

const styles = StyleSheet.create({
  emojiSelectorContainer: {
    position: 'absolute',
    bottom: 0,
    width: '100%',
    height: '50%',
    backgroundColor: 'white',
    borderTopLeftRadius: 15,
    borderTopRightRadius: 15,
    shadowColor: '#000',
    shadowOpacity: 0.3,
    shadowOffset: { width: 0, height: -2 },
    shadowRadius: 5,
    elevation: 5,
    padding: 10
  },
  closeModalButton: {
    position: 'absolute',
    top: 10,
    right: 10
  }
});

export default EmojiSelectorModal;
